@@ -2,7 +2,7 @@
  * bit_invader.h - declaration of class bitInvader and bSynth which
  *                         are a wavetable synthesizer
  *
- * Copyright (c) 2006 Andreas Brandmaier <andy/at/brandmaier/dot/de>
+ * Copyright (c) 2006-2008 Andreas Brandmaier <andy/at/brandmaier/dot/de>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -27,86 +27,115 @@
 #ifndef _BIT_INVADER_H
 #define _BIT_INVADER_H
 
-
-#include "instrument.h"
-#include "spc_bg_hndl_widget.h"
+#include "Instrument.h"
+#include "InstrumentView.h"
 #include "graph.h"
+#include "knob.h"
+#include "pixmap_button.h"
 #include "led_checkbox.h"
-#include "oscillator.h"
 
-class QPixmap;
-
-class knob;
-class notePlayHandle;
-class pixmapButton;
+class oscillator;
+class bitInvaderView;
 
 class bSynth
 {
 public:
-	bSynth(float* sample, int length, float _pitch, bool _interpolation, float factor, const sample_rate_t _sample_rate);
+	bSynth( float * sample, int length, notePlayHandle * _nph,
+			bool _interpolation, float factor, 
+			const sample_rate_t _sample_rate );
 	virtual ~bSynth();
 	
-	sample_t nextStringSample();	
+	sample_t nextStringSample();
 
 
 private:
-
 	int sample_index;
 	float sample_realindex;
-	int sample_length;
 	float* sample_shape;
-	float sample_step;	
+	notePlayHandle* nph;
+	const int sample_length;
+	const sample_rate_t sample_rate;
 
 	bool interpolation;
 	
 } ;
 
-class bitInvader : public instrument, public specialBgHandlingWidget
+class bitInvader : public Instrument
 {
 	Q_OBJECT
 public:
-	bitInvader(instrumentTrack * _channel_track );
+	bitInvader(InstrumentTrack * _instrument_track );
 	virtual ~bitInvader();
 
-	virtual void FASTCALL playNote( notePlayHandle * _n,
-						bool _try_parallelizing );
-	virtual void FASTCALL deleteNotePluginData( notePlayHandle * _n );
+	virtual void playNote( notePlayHandle * _n,
+						sampleFrame * _working_buffer );
+	virtual void deleteNotePluginData( notePlayHandle * _n );
 
 
-	virtual void FASTCALL saveSettings( QDomDocument & _doc,
+	virtual void saveSettings( QDomDocument & _doc,
 							QDomElement & _parent );
-	virtual void FASTCALL loadSettings( const QDomElement & _this );
+	virtual void loadSettings( const QDomElement & _this );
 
-	virtual QString nodeName( void ) const;
+	virtual QString nodeName() const;
 
-	virtual f_cnt_t desiredReleaseFrames( void ) const
+	virtual f_cnt_t desiredReleaseFrames() const
 	{
 		return( 64 );
 	}
 
+	virtual PluginView * instantiateView( QWidget * _parent );
 
-public slots:
-        void sampleSizeChanged( float _new_sample_length );
-        void sampleChanged( void );
+protected slots:
+	void lengthChanged();
+	void samplesChanged( int, int );
 
-        void interpolationToggle( bool value );
-        void normalizeToggle( bool value );
-        void smoothClicked( void  );
+	void normalize();
 
-        void sinWaveClicked( void );
-        void triangleWaveClicked( void );
-        void sqrWaveClicked( void );
-        void sawWaveClicked( void );
-        void noiseWaveClicked( void );
-        void usrWaveClicked( void );
-/*
-protected:
-	virtual void paintEvent( QPaintEvent * );
-*/
 
 private:
-	knob * m_sampleLengthKnob;
+	FloatModel  m_sampleLength;
+	graphModel  m_graph;
+	
+	BoolModel m_interpolation;
+	BoolModel m_normalize;
+	
+	float normalizeFactor;
+	
+	oscillator * m_osc;
 
+	friend class bitInvaderView;
+} ;
+
+
+
+class bitInvaderView : public InstrumentView
+{
+	Q_OBJECT
+public:
+	bitInvaderView( Instrument * _instrument,
+					QWidget * _parent );
+
+	virtual ~bitInvaderView() {};
+
+protected slots:
+	//void sampleSizeChanged( float _new_sample_length );
+
+	void interpolationToggled( bool value );
+	void normalizeToggled( bool value );
+
+	void sinWaveClicked();
+	void triangleWaveClicked();
+	void sqrWaveClicked();
+	void sawWaveClicked();
+	void noiseWaveClicked();
+	void usrWaveClicked();
+	
+	void smoothClicked( void  );
+
+private:
+	virtual void modelChanged();
+
+	knob * m_sampleLengthKnob;
 	pixmapButton * sinWaveBtn;
 	pixmapButton * triangleWaveBtn;
 	pixmapButton * sqrWaveBtn;
@@ -121,18 +150,8 @@ private:
 	ledCheckBox * m_interpolationToggle;
 	ledCheckBox * m_normalizeToggle;
 
-	int sample_length;
-        float* sample_shape;
-
-	bool interpolation;	                
-	bool normalize;
-	float normalizeFactor;
-	
-	oscillator * m_osc;
 } ;
 
 
-#include "bit_invader.moc"
-
 
 #endif
