@@ -1,10 +1,8 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * config_mgr.cpp - implementation of class configManager
  *
- * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2005-2011 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +22,6 @@
  *
  */
 
-
 #include <QtXml/QDomElement>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
@@ -244,7 +241,9 @@ void configManager::loadConfigFile()
 
 	if( cfg_file.open( QIODevice::ReadOnly ) )
 	{
-		if( dom_tree.setContent( &cfg_file ) )
+		QString errorString;
+		int errorLine, errorCol;
+		if( dom_tree.setContent( &cfg_file, false, &errorString, &errorLine, &errorCol ) )
 		{
 			// get the head information from the DOM
 			QDomElement root = dom_tree.documentElement();
@@ -314,6 +313,14 @@ void configManager::loadConfigFile()
 		#endif
 			setBackgroundArtwork( value( "paths", "backgroundartwork" ) );
 		}
+		else
+		{
+			QMessageBox::warning( NULL, MainWindow::tr( "Configuration file" ),
+									MainWindow::tr( "Error while parsing configuration file at line %1:%2: %3" ).
+													arg( errorLine ).
+													arg( errorCol ).
+													arg( errorString ) );
+		}
 		cfg_file.close();
 	}
 
@@ -444,10 +451,8 @@ void configManager::saveConfigFile()
 		return;
 	}
 
-	outfile.write( xml.toUtf8().constData(), xml.length() );
+	outfile.write( xml.toUtf8() );
 	outfile.close();
 }
 
 
-
-#endif
