@@ -43,6 +43,7 @@
 #endif
 
 #include <math.h>
+#include <algorithm>
 
 #include "piano_roll.h"
 #include "bb_track_container.h"
@@ -75,7 +76,6 @@ extern Keys whiteKeys[];	// defined in piano_widget.cpp
 
 
 // some constants...
-const int INITIAL_PIANOROLL_WIDTH = 840;
 const int INITIAL_PIANOROLL_HEIGHT = 480;
 
 const int SCROLLBAR_SIZE = 16;
@@ -137,7 +137,7 @@ const int DEFAULT_PR_PPT = KEY_LINE_HEIGHT * DefaultStepsPerTact;
 pianoRoll::pianoRoll() :
 	m_nemStr( QVector<QString>() ),
 	m_noteEditMenu( NULL ),
-	m_signalMapper( NULL ),
+	m_semiToneMarkerMenu( NULL ),
 	m_zoomingModel(),
 	m_quantizeModel(),
 	m_noteLenModel(),
@@ -172,19 +172,49 @@ pianoRoll::pianoRoll() :
 	m_nemStr.push_back( tr( "Note Volume" ) );
 	m_nemStr.push_back( tr( "Note Panning" ) );
 	
-	m_signalMapper = new QSignalMapper( this );
+	QSignalMapper * signalMapper = new QSignalMapper( this );
 	m_noteEditMenu = new QMenu( this );
 	m_noteEditMenu->clear();
 	for( int i=0; i<m_nemStr.size(); ++i )
 	{
 		QAction * act = new QAction( m_nemStr.at(i), this );
-		connect( act, SIGNAL(triggered()), m_signalMapper, SLOT(map()) );
-		m_signalMapper->setMapping( act, i );
+		connect( act, SIGNAL(triggered()), signalMapper, SLOT(map()) );
+		signalMapper->setMapping( act, i );
 		m_noteEditMenu->addAction( act );
 	}
-	connect( m_signalMapper, SIGNAL(mapped(int)), 
+	connect( signalMapper, SIGNAL(mapped(int)),
 			this, SLOT(changeNoteEditMode(int)) );
 	
+	signalMapper = new QSignalMapper( this );
+	m_semiToneMarkerMenu = new QMenu( this );
+
+	QAction * act = new QAction( tr("Mark/unmark current semitone"), this );
+	connect( act, SIGNAL(triggered()), signalMapper, SLOT(map()) );
+	signalMapper->setMapping( act, static_cast<int>( stmaMarkCurrentSemiTone ) );
+	m_semiToneMarkerMenu->addAction( act );
+
+	act = new QAction( tr("Mark current scale"), this );
+	act->setEnabled( false );
+	connect( act, SIGNAL(triggered()), signalMapper, SLOT(map()) );
+	connect( this, SIGNAL(semiToneMarkerMenuScaleSetEnabled(bool)), act, SLOT(setEnabled(bool)) );
+	signalMapper->setMapping( act, static_cast<int>( stmaMarkCurrentScale ) );
+	m_semiToneMarkerMenu->addAction( act );
+
+	act = new QAction( tr("Mark current chord"), this );
+	act->setEnabled( false );
+	connect( act, SIGNAL(triggered()), signalMapper, SLOT(map()) );
+	connect( this, SIGNAL(semiToneMarkerMenuChordSetEnabled(bool)), act, SLOT(setEnabled(bool)) );
+	signalMapper->setMapping( act, static_cast<int>( stmaMarkCurrentChord ) );
+	m_semiToneMarkerMenu->addAction( act );
+
+	act = new QAction( tr("Unmark all"), this );
+	connect( act, SIGNAL(triggered()), signalMapper, SLOT(map()) );
+	signalMapper->setMapping( act, static_cast<int>( stmaUnmarkAll ) );
+	m_semiToneMarkerMenu->addAction( act );
+
+	connect( signalMapper, SIGNAL(mapped(int)),
+			this, SLOT(markSemiTone(int)) );
+
 	// init pixmaps
 	if( s_whiteKeySmallPm == NULL )
 	{
@@ -471,6 +501,52 @@ pianoRoll::pianoRoll() :
 					this, SLOT( quantizeChanged() ) );
 
 
+	const ChordCreator::ChordTable & chord_table = ChordCreator::ChordTable::getInstance();
+
+	// setup scale-stuff
+	QLabel * scale_lbl = new QLabel( m_toolBar );
+	scale_lbl->setPixmap( embed::getIconPixmap( "scale" ) );
+
+	m_scaleModel.addItem( tr("No scale") );
+	for( int i = 0; i < chord_table.size(); ++i )
+	{
+		if( chord_table[i].isScale() )
+		{
+			m_scaleModel.addItem( chord_table[i].getName() );
+		}
+	}
+
+	m_scaleModel.setValue( 0 );
+	m_scaleComboBox = new comboBox( m_toolBar );
+	m_scaleComboBox->setModel( &m_scaleModel );
+	m_scaleComboBox->setFixedSize( 105, 22 );
+	// change can update m_semiToneMarkerMenu
+	connect( &m_scaleModel, SIGNAL( dataChanged() ),
+					this, SLOT( updateSemiToneMarkerMenu() ) );
+
+
+	// setup chord-stuff
+	QLabel * chord_lbl = new QLabel( m_toolBar );
+	chord_lbl->setPixmap( embed::getIconPixmap( "chord" ) );
+
+	m_chordModel.addItem( tr("No chord") );
+	for( int i = 0; i < chord_table.size(); ++i )
+	{
+		if( ! chord_table[i].isScale() )
+		{
+			m_chordModel.addItem( chord_table[i].getName() );
+		}
+	}
+
+	m_chordModel.setValue( 0 );
+	m_chordComboBox = new comboBox( m_toolBar );
+	m_chordComboBox->setModel( &m_chordModel );
+	m_chordComboBox->setFixedSize( 105, 22 );
+	// change can update m_semiToneMarkerMenu
+	connect( &m_chordModel, SIGNAL( dataChanged() ),
+					this, SLOT( updateSemiToneMarkerMenu() ) );
+
+
 	tb_layout->addSpacing( 5 );
 	tb_layout->addWidget( m_playButton );
 	tb_layout->addWidget( m_recordButton );
@@ -499,6 +575,14 @@ pianoRoll::pianoRoll() :
 	tb_layout->addWidget( note_len_lbl );
 	tb_layout->addSpacing( 4 );
 	tb_layout->addWidget( m_noteLenComboBox );
+	tb_layout->addSpacing( 10 );
+	tb_layout->addWidget( scale_lbl );
+	tb_layout->addSpacing( 4 );
+	tb_layout->addWidget( m_scaleComboBox );
+	tb_layout->addSpacing( 10 );
+	tb_layout->addWidget( chord_lbl );
+	tb_layout->addSpacing( 4 );
+	tb_layout->addWidget( m_chordComboBox );
 	tb_layout->addStretch();
 
 	// setup our actual window
@@ -515,13 +599,14 @@ pianoRoll::pianoRoll() :
 	if( engine::mainWindow()->workspace() )
 	{
 		engine::mainWindow()->workspace()->addSubWindow( this );
-		parentWidget()->resize( INITIAL_PIANOROLL_WIDTH,
+		parentWidget()->setMinimumWidth( tb_layout->minimumSize().width()+10 );
+		parentWidget()->resize( tb_layout->minimumSize().width()+10,
 						INITIAL_PIANOROLL_HEIGHT );
 		parentWidget()->hide();
 	}
 	else
 	{
-		resize( INITIAL_PIANOROLL_WIDTH, INITIAL_PIANOROLL_HEIGHT );
+		resize( tb_layout->minimumSize().width(), INITIAL_PIANOROLL_HEIGHT );
 		hide();
 	}
 
@@ -537,6 +622,72 @@ void pianoRoll::changeNoteEditMode( int i )
 }
 
 
+void pianoRoll::markSemiTone( int i )
+{
+	const int key = getKey( mapFromGlobal( m_semiToneMarkerMenu->pos() ).y() );
+	const ChordCreator::Chord * chord = 0;
+
+	switch( static_cast<semiToneMarkerAction>( i ) )
+	{
+		case stmaUnmarkAll:
+			m_markedSemiTones.clear();
+			break;
+		case stmaMarkCurrentSemiTone:
+		{
+			QList<int>::iterator i = qFind( m_markedSemiTones.begin(), m_markedSemiTones.end(), key );
+			if( i != m_markedSemiTones.end() )
+			{
+				m_markedSemiTones.erase( i );
+			}
+			else
+			{
+				m_markedSemiTones.push_back( key );
+			}
+			break;
+		}
+		case stmaMarkCurrentScale:
+			chord = & ChordCreator::ChordTable::getInstance()
+					.getScaleByName( m_scaleModel.currentText() );
+		case stmaMarkCurrentChord:
+		{
+			if( ! chord )
+			{
+				chord = & ChordCreator::ChordTable::getInstance()
+						.getChordByName( m_chordModel.currentText() );
+			}
+
+			if( chord->isEmpty() )
+			{
+				break;
+			}
+			else if( chord->isScale() )
+			{
+				m_markedSemiTones.clear();
+			}
+
+			const int first = chord->isScale() ? 0 : key;
+			const int last = chord->isScale() ? NumKeys : key + chord->last();
+			const int cap = chord->isScale() ? KeysPerOctave : chord->last();
+
+			for( int i = first; i <= last; i++ )
+			{
+				if( chord->hasSemiTone( std::abs( key - i ) % cap ) )
+				{
+					m_markedSemiTones.push_back( i );
+				}
+			}
+			break;
+		}
+		default:
+			;
+	}
+
+	qSort( m_markedSemiTones.begin(), m_markedSemiTones.end(), qGreater<int>() );
+	QList<int>::iterator new_end = std::unique( m_markedSemiTones.begin(), m_markedSemiTones.end() );
+	m_markedSemiTones.erase( new_end, m_markedSemiTones.end() );
+}
+
+
 pianoRoll::~pianoRoll()
 {
 }
@@ -927,8 +1078,8 @@ void pianoRoll::keyPressEvent( QKeyEvent * _ke )
 						m_action == ActionResizeNote )
 				{
 					dragNotes( m_lastMouseX, m_lastMouseY,
-							_ke->modifiers() &
-							Qt::AltModifier );
+							_ke->modifiers() & Qt::AltModifier,
+							_ke->modifiers() & Qt::ShiftModifier );
 				}
 			}
 			_ke->accept();
@@ -955,8 +1106,8 @@ void pianoRoll::keyPressEvent( QKeyEvent * _ke )
 						m_action == ActionResizeNote )
 				{
 					dragNotes( m_lastMouseX, m_lastMouseY,
-							_ke->modifiers() &
-							Qt::AltModifier );
+							_ke->modifiers() & Qt::AltModifier,
+							_ke->modifiers() & Qt::ShiftModifier );
 				}
 			}
 			_ke->accept();
@@ -995,8 +1146,8 @@ void pianoRoll::keyPressEvent( QKeyEvent * _ke )
 						m_action == ActionResizeNote )
 				{
 					dragNotes( m_lastMouseX, m_lastMouseY,
-							_ke->modifiers() &
-							Qt::AltModifier );
+							_ke->modifiers() & Qt::AltModifier,
+							_ke->modifiers() & Qt::ShiftModifier );
 				}				
 				
 			}
@@ -1033,8 +1184,8 @@ void pianoRoll::keyPressEvent( QKeyEvent * _ke )
 						m_action == ActionResizeNote )
 				{
 					dragNotes( m_lastMouseX, m_lastMouseY,
-							_ke->modifiers() &
-							Qt::AltModifier );
+							_ke->modifiers() & Qt::AltModifier,
+							_ke->modifiers() & Qt::ShiftModifier );
 				}				
 				
 			}
@@ -1369,11 +1520,15 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 			else if( _me->button() == Qt::LeftButton &&
 							m_editMode == ModeDraw )
 			{
+				// whether this action creates new note(s) or not
+				bool is_new_note = false;
+
 				note * created_new_note = NULL;
 				// did it reach end of vector because
 				// there's no note??
 				if( it == notes.begin()-1 )
 				{
+					is_new_note = true;
 					m_pattern->setType( pattern::MelodyPattern );
 
 					// then set new note
@@ -1386,13 +1541,35 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 					// because live notes should still be quantized at the half.
 					midiTime note_pos( pos_ticks - ( quantization() / 2 ) );
 					midiTime note_len( newNoteLen() );
-		
+
 					note new_note( note_len, note_pos, key_num );
 					new_note.setSelected( true );
 					new_note.setPanning( m_lastNotePanning );
 					new_note.setVolume( m_lastNoteVolume );
 					created_new_note = m_pattern->addNote( new_note );
 
+					const ChordCreator::Chord & chord = ChordCreator::ChordTable::getInstance()
+						.getChordByName( m_chordModel.currentText() );
+
+					if( ! chord.isEmpty() )
+					{
+						// if a chord is selected, create following notes in chord
+						// or arpeggio mode
+						const bool arpeggio = _me->modifiers() & Qt::ShiftModifier;
+						for( int i = 1; i < chord.size(); i++ )
+						{
+							if( arpeggio )
+							{
+								note_pos += note_len;
+							}
+							note new_note( note_len, note_pos, key_num + chord[i] );
+							new_note.setSelected( true );
+							new_note.setPanning( m_lastNotePanning );
+							new_note.setVolume( m_lastNoteVolume );
+							m_pattern->addNote( new_note );
+						}
+					}
+
 					// reset it so that it can be used for
 					// ops (move, resize) after this
 					// code-block
@@ -1495,7 +1672,7 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 					
 					// if they're holding shift, copy all selected notes 
 					if( //*it != created_new_note &&
-					   _me->modifiers() & Qt::ShiftModifier )
+					   ! is_new_note && _me->modifiers() & Qt::ShiftModifier )
 					{
 						// vector to hold new notes until we're through the loop
 						QVector<note> newNotes;
@@ -1574,14 +1751,23 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 		}
 		else if( _me->y() < keyAreaBottom() )
 		{
-			// clicked on keyboard on the left - play note
-			m_lastKey = key_num;
-			if( ! m_recording && ! engine::getSong()->isPlaying() )
+			// clicked on keyboard on the left
+			if( _me->buttons() == Qt::RightButton )
 			{
-				int v = ( (float) x ) / ( (float) WHITE_KEY_WIDTH ) * 127;
-				m_pattern->instrumentTrack()->processInEvent(
-							midiEvent( MidiNoteOn, 0, key_num, v ),
-							midiTime() );
+				// right click, tone marker contextual menu
+				m_semiToneMarkerMenu->popup( mapToGlobal( QPoint( _me->x(), _me->y() ) ) );
+			}
+			else
+			{
+				// left click - play the note
+				m_lastKey = key_num;
+				if( ! m_recording && ! engine::getSong()->isPlaying() )
+				{
+					int v = ( (float) x ) / ( (float) WHITE_KEY_WIDTH ) * 127;
+					m_pattern->instrumentTrack()->processInEvent(
+								midiEvent( MidiNoteOn, 0, key_num, v ),
+								midiTime() );
+				}
 			}
 		}
 		else
@@ -1765,7 +1951,15 @@ void pianoRoll::computeSelectedNotes(bool shift)
 				pos_ticks + len_ticks > sel_pos_start &&
 				pos_ticks < sel_pos_end )
 			{
-				( *it )->setSelected( true );
+				// remove from selection when holding shift
+				if( shift && ( *it )->selected() )
+				{
+					( *it )->setSelected(false);
+				}
+				else
+				{
+					( *it )->setSelected(true);
+				}
 			}
 		}
 	}
@@ -1936,7 +2130,12 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 				pauseTestNotes();
 			}
 			
-			dragNotes(_me->x(), _me->y(), _me->modifiers() & Qt::AltModifier);
+			dragNotes(
+				_me->x(),
+				_me->y(),
+				_me->modifiers() & Qt::AltModifier,
+				_me->modifiers() & Qt::ShiftModifier
+			);
 			
 			if( replay_note && m_action == ActionMoveNote )
 			{
@@ -2310,7 +2509,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 
 
 
-void pianoRoll::dragNotes( int x, int y, bool alt )
+void pianoRoll::dragNotes( int x, int y, bool alt, bool shift )
 {
 	// dragging one or more notes around
 		
@@ -2347,7 +2546,10 @@ void pianoRoll::dragNotes( int x, int y, bool alt )
 			off_key += 0 - (m_moveBoundaryBottom + off_key);
 		}
 	}
-	
+
+	int shift_offset = 0;
+	int shift_ref_pos = -1;
+
 	// get note-vector of current pattern
 	const NoteVector & notes = m_pattern->notes();
 
@@ -2355,6 +2557,19 @@ void pianoRoll::dragNotes( int x, int y, bool alt )
 	NoteVector::ConstIterator it = notes.begin();
 	while( it != notes.end() )
 	{
+		const int pos = ( *it )->pos().getTicks();
+		// when resizing a note and holding shift: shift the following
+		// notes to preserve the melody
+		if( m_action == ActionResizeNote && shift )
+		{
+			int shifted_pos = ( *it )->oldPos().getTicks() + shift_offset;
+			if( shifted_pos && pos == shift_ref_pos )
+			{
+				shifted_pos -= off_ticks;
+			}
+			( *it )->setPos( midiTime( shifted_pos ) );
+		}
+
 		if( ( *it )->selected() )
 		{
 			
@@ -2391,6 +2606,16 @@ void pianoRoll::dragNotes( int x, int y, bool alt )
 				{
 					ticks_new = 1;
 				}
+				else if( shift )
+				{
+					// when holding shift: update the offset used to shift
+					// the following notes
+					if( pos > shift_ref_pos )
+					{
+						shift_offset += off_ticks;
+						shift_ref_pos = pos;
+					}
+				}
 				( *it )->setLength( midiTime( ticks_new ) );
 				
 				m_lenOfNewNotes = ( *it )->length();
@@ -2570,6 +2795,22 @@ void pianoRoll::paintEvent( QPaintEvent * _pe )
 		++key;
 	}
 
+	// display note marks
+	for( int i = 0; i < m_markedSemiTones.size(); i++ )
+	{
+		const int key_num = m_markedSemiTones.at( i );
+		const int y = keyAreaBottom() + 5
+			- KEY_LINE_HEIGHT * ( key_num - m_startKey + 1 );
+
+		if( y > keyAreaBottom() )
+		{
+			break;
+		}
+
+		p.fillRect( WHITE_KEY_WIDTH, y,
+				width() - 10, 1,
+							QColor( 64, 64 + ( key_num % KeysPerOctave ) * 7, 96 + key_num ) );
+	}
 
 	// erase the area below the piano, because there might be keys that 
 	// should be only half-visible
@@ -3525,6 +3766,21 @@ int pianoRoll::quantization() const
 
 
 
+void pianoRoll::updateSemiToneMarkerMenu()
+{
+	const ChordCreator::Chord & scale = ChordCreator::ChordTable::getInstance()
+					.getScaleByName( m_scaleModel.currentText() );
+
+	const ChordCreator::Chord & chord = ChordCreator::ChordTable::getInstance()
+					.getChordByName( m_chordModel.currentText() );
+
+	emit semiToneMarkerMenuScaleSetEnabled( ! scale.isEmpty() );
+	emit semiToneMarkerMenuChordSetEnabled( ! chord.isEmpty() );
+}
+
+
+
+
 midiTime pianoRoll::newNoteLen() const
 {
 	if( m_noteLenModel.value() == 0 )
