@@ -112,8 +112,11 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 				"disablechannelactivityindicators" ).toInt() ),
 	m_manualChPiano( configManager::inst()->value( "ui",
 					"manualchannelpiano" ).toInt() ),
+	m_smoothScroll( configManager::inst()->value( "ui", "smoothscroll" ).toInt() ),
 	m_oneInstrumentTrackWindow( configManager::inst()->value( "ui",
-					"oneinstrumenttrackwindow" ).toInt() )
+					"oneinstrumenttrackwindow" ).toInt() ),
+	m_compactTrackButtons( configManager::inst()->value( "ui",
+					"compacttrackbuttons" ).toInt() )
 {
 	setWindowIcon( embed::getIconPixmap( "setup_general" ) );
 	setWindowTitle( tr( "Setup LMMS" ) );
@@ -182,7 +185,7 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 
 
 	tabWidget * misc_tw = new tabWidget( tr( "MISC" ), general );
-	misc_tw->setFixedHeight( 138 );
+	misc_tw->setFixedHeight( 156 );
 
 	ledCheckBox * enable_tooltips = new ledCheckBox(
 							tr( "Enable tooltips" ),
@@ -234,6 +237,14 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	connect( hqaudio, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleHQAudioDev( bool ) ) );
 
+	ledCheckBox * compacttracks = new ledCheckBox(
+				tr( "Compact track buttons" ),
+								misc_tw );
+	compacttracks->move( 10, 126 );
+	compacttracks->setChecked( m_compactTrackButtons );
+	connect( compacttracks, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleCompactTrackButtons( bool ) ) );
+
 
 
 	gen_layout->addWidget( bufsize_tw );
@@ -453,7 +464,7 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	tabWidget * ui_fx_tw = new tabWidget( tr( "UI effects vs. "
 						"performance" ).toUpper(),
 								performance );
-	ui_fx_tw->setFixedHeight( 70 );
+	ui_fx_tw->setFixedHeight( 90 );
 
 	ledCheckBox * disable_ch_act_ind = new ledCheckBox(
 				tr( "Disable channel activity indicators" ),
@@ -472,6 +483,13 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	connect( manual_ch_piano, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleManualChPiano( bool ) ) );
 
+	ledCheckBox * smoothScroll = new ledCheckBox(
+			tr( "Smooth scroll in Song Editor" ), ui_fx_tw );
+	smoothScroll->move( 10, 60 );
+	smoothScroll->setChecked( m_smoothScroll );
+	connect( smoothScroll, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleSmoothScroll( bool ) ) );
+
 
 
 	perf_layout->addWidget( ui_fx_tw );
@@ -739,8 +757,12 @@ void setupDialog::accept()
 					QString::number( m_disableChActInd ) );
 	configManager::inst()->setValue( "ui", "manualchannelpiano",
 					QString::number( m_manualChPiano ) );
+	configManager::inst()->setValue( "ui", "smoothscroll",
+					QString::number( m_smoothScroll ) );
 	configManager::inst()->setValue( "ui", "oneinstrumenttrackwindow",
 					QString::number( m_oneInstrumentTrackWindow ) );
+	configManager::inst()->setValue( "ui", "compacttrackbuttons",
+					QString::number( m_compactTrackButtons ) );
 
 	configManager::inst()->setWorkingDir( m_workingDir );
 	configManager::inst()->setVSTDir( m_vstDir );
@@ -897,6 +919,24 @@ void setupDialog::toggleManualChPiano( bool _enabled )
 
 
 
+void setupDialog::toggleSmoothScroll( bool _enabled )
+{
+	m_smoothScroll = _enabled;
+}
+
+
+
+
+
+void setupDialog::toggleCompactTrackButtons( bool _enabled )
+{
+	m_compactTrackButtons = _enabled;
+}
+
+
+
+
+
 void setupDialog::toggleOneInstrumentTrackWindow( bool _enabled )
 {
 	m_oneInstrumentTrackWindow = _enabled;
