@@ -2,7 +2,7 @@
  * InstrumentTrack.cpp - implementation of instrument-track-class
  *                        (window + data-structures)
  *
- * Copyright (c) 2004-2011 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -386,6 +386,7 @@ void InstrumentTrack::processOutEvent( const midiEvent & _me,
 			if( k >= 0 && k < NumKeys &&
 						--m_runningMidiNotes[k] <= 0 )
 			{
+				m_runningMidiNotes[k] = qMax( 0, m_runningMidiNotes[k] );
 				m_instrument->handleMidiEvent(
 	midiEvent( MidiNoteOff, midiPort()->realOutputChannel(), k, 0 ),
 									_time );
@@ -613,7 +614,7 @@ bool InstrumentTrack::play( const midiTime & _start,
 		{
 			cur_start -= p->startPosition();
 		}
-		if( p->frozen() && !engine::getSong()->isExporting() )
+		if( p->isFrozen() && !engine::getSong()->isExporting() )
 		{
 			if( cur_start > 0 )
 			{
@@ -671,6 +672,14 @@ bool InstrumentTrack::play( const midiTime & _start,
 								note_frames,
 								*cur_note );
 				note_play_handle->setBBTrack( bb_track );
+				// are we playing global song?
+				if( _tco_num < 0 )
+				{
+					// then set song-global offset of pattern in order to
+					// properly perform the note detuning
+					note_play_handle->setSongGlobalParentOffset( p->startPosition() );
+				}
+
 #if LMMS_SINGERBOT_SUPPORT
 				note_play_handle->setPatternIndex( note_idx );
 #endif
@@ -885,12 +894,23 @@ InstrumentTrackView::InstrumentTrackView( InstrumentTrack * _it,
 			m_tlb, SLOT( update() ) );
 
 	// creation of widgets for track-settings-widget
+	int widgetWidth;
+	if( configManager::inst()->value( "ui",
+					  "compacttrackbuttons" ).toInt() )
+	{
+		widgetWidth = DEFAULT_SETTINGS_WIDGET_WIDTH_COMPACT;
+	}
+	else 
+	{
+		widgetWidth = DEFAULT_SETTINGS_WIDGET_WIDTH;
+	}
+
 	m_volumeKnob = new knob( knobSmall_17, getTrackSettingsWidget(),
 							tr( "Volume" ) );
 	m_volumeKnob->setVolumeKnob( true );
 	m_volumeKnob->setModel( &_it->m_volumeModel );
 	m_volumeKnob->setHintText( tr( "Volume:" ) + " ", "%" );
-	m_volumeKnob->move( DEFAULT_SETTINGS_WIDGET_WIDTH-24*2, 4 );
+	m_volumeKnob->move( widgetWidth-2*24, 4 );
 	m_volumeKnob->setLabel( tr( "VOL" ) );
 	m_volumeKnob->show();
 	m_volumeKnob->setWhatsThis( tr( volume_help ) );
@@ -899,11 +919,10 @@ InstrumentTrackView::InstrumentTrackView( InstrumentTrack * _it,
 							tr( "Panning" ) );
 	m_panningKnob->setModel( &_it->m_panningModel );
 	m_panningKnob->setHintText( tr( "Panning:" ) + " ", "%" );
-	m_panningKnob->move( DEFAULT_SETTINGS_WIDGET_WIDTH-24, 4 );
+	m_panningKnob->move( widgetWidth-24, 4 );
 	m_panningKnob->setLabel( tr( "PAN" ) );
 	m_panningKnob->show();
 
-
 	m_midiMenu = new QMenu( tr( "MIDI" ), this );
 
 	// sequenced MIDI?
@@ -943,7 +962,7 @@ InstrumentTrackView::InstrumentTrackView( InstrumentTrack * _it,
 						QColor( 64, 255, 16 ),
 						getTrackSettingsWidget() );
 	m_activityIndicator->setGeometry(
-			DEFAULT_SETTINGS_WIDGET_WIDTH-2*24-11, 2, 8, 28 );
+					 widgetWidth-2*24-11, 2, 8, 28 );
 	m_activityIndicator->show();
 	connect( m_activityIndicator, SIGNAL( pressed() ),
 				this, SLOT( activityIndicatorPressed() ) );
